@@ -4,7 +4,7 @@ use strict;
 use vars qw($VERSION);
 use Carp;
 
-$VERSION = '2.12';
+$VERSION = '2.14';
 
 
 # LOAD FILTERING MODULE...
@@ -72,15 +72,9 @@ sub is_block
 	return !$ishash;
 }
 
-
-my $EOP = qr/\n|\Z/;
-my $CUT = qr/\n=cut.*$EOP/;
-my $pod_or_DATA = qr/ ^=(?:head[1-4]|item) .*? $CUT
-                    | ^=pod .*? $CUT
-                    | ^=for .*? $EOP
-                    | ^=begin \s* (\S+) .*? \n=end \s* \1 .*? $EOP
-                    | ^__(DATA|END)__\n.*
-                    /smx;
+my $pod_or_DATA = qr/ ^=[A-Za-z] .*? ^=cut (?![A-Za-z]) .*? $
+		    | ^__(DATA|END)__\n.*
+		    /smx;
 
 my $casecounter = 1;
 sub filter_blocks
@@ -101,10 +95,22 @@ sub filter_blocks
 		if (defined $pos[0])
 		{
 			my $pre = substr($source,$pos[0],$pos[1]); # matched prefix
-			$text .= $pre . substr($source,$pos[2],$pos[18]-$pos[2]);
+                        my $iEol;
+                        if( substr($source,$pos[4],$pos[5]) eq '/' && # 1st delimiter
+                            substr($source,$pos[2],$pos[3]) eq '' && # no op like 'm'
+                            index( substr($source,$pos[16],$pos[17]), 'x' ) == -1 && # no //x
+                            ($iEol = index( $source, "\n", $pos[4] )) > 0         &&
+                            $iEol < $pos[8] ){ # embedded newlines
+                            # If this is a pattern, it isn't compatible with Switch. Backup past 1st '/'.
+                            pos( $source ) = $pos[6];
+			    $text .= $pre . substr($source,$pos[2],$pos[6]-$pos[2]);
+			} else {
+			    $text .= $pre . substr($source,$pos[2],$pos[18]-$pos[2]);
+			}
 			next component;
 		}
-		if ($source =~ m/\G\s*($pod_or_DATA)/gc) {
+		if ($source =~ m/(\G\s*$pod_or_DATA)/gc) {
+			$text .= $1;
 			next component;
 		}
 		@pos = Text::Balanced::_match_variable(\$source,qr/\s*/);
@@ -502,8 +508,8 @@ Switch - A switch statement for Perl
 
 =head1 VERSION
 
-This document describes version 2.11 of Switch,
-released Nov 22, 2006.
+This document describes version 2.14 of Switch,
+released Dec 29, 2008.
 
 =head1 SYNOPSIS
 
@@ -513,10 +519,9 @@ released Nov 22, 2006.
 	case 1		{ print "number 1" }
 	case "a"	{ print "string a" }
 	case [1..10,42]	{ print "number in list" }
-	case (@array)	{ print "number in list" }
+	case (\@array)	{ print "number in list" }
 	case /\w+/	{ print "pattern" }
 	case qr/\w+/	{ print "pattern" }
-	case (%hash)	{ print "entry in hash" }
 	case (\%hash)	{ print "entry in hash" }
 	case (\&sub)	{ print "arg to subroutine" }
 	else		{ print "previous case not true" }
@@ -830,7 +835,7 @@ and then treats the two resulting references as arguments to C<&&>:
 
 This boolean expression is inevitably true, since both references are
 non-false. Fortunately, the overloaded C<'bool'> operator catches this
-situation and flags it as a error. 
+situation and flags it as an error. 
 
 =head1 DEPENDENCIES
 
@@ -839,8 +844,9 @@ and requires both these modules to be installed.
 
 =head1 AUTHOR
 
-Damian Conway (damian@conway.org). The maintainer of this module is now Rafael
-Garcia-Suarez (rgarciasuarez@gmail.com).
+Damian Conway (damian@conway.org). This module is now maintained by Rafael
+Garcia-Suarez (rgarciasuarez@gmail.com) and more generally by the Perl 5
+Porters (perl5-porters@perl.org), as part of the Perl core.
 
 =head1 BUGS
 
@@ -849,7 +855,11 @@ Bug reports and other feedback are most welcome.
 
 =head1 LIMITATIONS
 
-Due to the heuristic nature of Switch.pm's source parsing, the presence
+Due to the heuristic nature of Switch.pm's source parsing, the presence of
+regexes with embedded newlines that are specified with raw C</.../>
+delimiters and don't have a modifier C<//x> are indistinguishable from
+code chunks beginning with the division operator C</>. As a workaround
+you must use C<m/.../> or C<m?...?> for such patterns. Also, the presence
 of regexes specified with raw C<?...?> delimiters may cause mysterious
 errors. The workaround is to use C<m?...?> instead.
 
@@ -863,6 +873,6 @@ use smaller source files.
 
 =head1 COPYRIGHT
 
-    Copyright (c) 1997-2006, Damian Conway. All Rights Reserved.
+    Copyright (c) 1997-2008, Damian Conway. All Rights Reserved.
     This module is free software. It may be used, redistributed
         and/or modified under the same terms as Perl itself.
